@@ -18,11 +18,11 @@ __init__.py
 
 from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN_vuelos, \
      load_medical_costs, load_stroke, load_wind_prediction, load_titanic, load_crabs, \
-          load_life_expectancy, load_electric_devices, load_energy 
+          load_life_expectancy, load_electric_devices, load_energy, load_arxiv, load_attrition 
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
-__version__ = '0.0.12'
+__version__ = '0.1.1'
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -37,5 +37,7 @@ __all__ = ['fetch_apa_data',
            'load_crabs',
            'load_life_expectancy', 
            'load_electric_devices',
-           'load_energy'
+           'load_energy',
+           'load_arxiv',
+           'load_attrition'
            ]
\ No newline at end of file
