@@ -18,6 +18,7 @@ setup.py
 from apafib.config import DATALINK, datasets
 import pandas as pd
 from sklearn.utils import Bunch
+import remotezip
 
 def fetch_apa_data(name, version, target_column, return_X_y=False, as_frame=True):
     """_dataset fetching function_
@@ -103,6 +104,19 @@ def load_electric_devices():
 def load_energy():
     return fetch_dataset('Energy')
 
+def load_attrition():
+    return fetch_dataset('attrition')
+
+def load_arxiv():
+    bk = remotezip.RemoteZip('http://www.cs.upc.edu/~bejar/datasets/arxiv.zip', initial_buffer_size=6_000_000)
+    text = []
+    labels = []
+    for f in sorted([fn for fn in bk.namelist() if '0' in fn]):
+        labels.append(f.split('/')[1].lower())
+        text.append(str(bk.read(f)).replace('\\n',' '))
+
+    return text, labels
+
 
 
 
